SuperLU: EXAMPLE/dfgmr.c File Reference

SuperLU 7.0.1

Macros | Functions
dfgmr.c File Reference
Example

Flexible GMRES from ITSOL developed by Yousef Saad. More...

`#include "slu_ddefs.h"`
Include dependency graph for dfgmr.c:

## Macros
#define | epsmac 1.0e-16

## Functions
double | ddot_ (int *, double[], int *, double[], int *)
double | dnrm2_ (int *, double[], int *)
int | dfgmr (int n, void(*dmatvec)(double, double[], double, double[]), void(*dpsolve)(int, double[], double[]), double *rhs, double *sol, double tol, int im, int *itmax, FILE *fits)
| Simple version of the ARMS preconditioned FGMRES algorithm. More...

## Macro Definition Documentation

## ◆ epsmac

#define epsmac 1.0e-16

## Function Documentation

## ◆ ddot_()

double ddot_ | ( | int * | ,
|  | double | [],
|  | int * | ,
|  | double | [],
|  | int * |
| ) |  |

## ◆ dfgmr()

int dfgmr | ( | int | n,
|  | void(*)(double, double[], double, double[]) | dmatvec,
|  | void(*)(int, double[], double[]) | dpsolve,
|  | double * | rhs,
|  | double * | sol,
|  | double | tol,
|  | int | im,
|  | int * | itmax,
|  | FILE * | fits
| ) |  |

Y. S. Dec. 2000. – Apr. 2008

internal work arrays: vv = work array of length [im+1][n] (used to store the Arnoldi basis) hh = work array of length [im][im+1] (Householder matrix) z = work array of length [im][n] to store preconditioned vectors

Parameters

  [in] | n | Dimension of vectors and matrices.
  [in] | dmatvec | Operation for matrix-vector multiplication.
  [in] | dpsolve | (right) preconditioning operation. Can be a NULL pointer (GMRES without preconditioner)
  [in] | rhs | Real vector of length n containing the right hand side.
  [in,out] | sol | In: Real vector of length n containing an initial guess to the solution on input. Out: Contains an approximate solution (upon successful return).
  [in] | tol | Tolerance for stopping iteration
  [in] | im | Krylov subspace dimension
  [in,out] | itmax | In: max number of iterations allowed. Out: number of steps required to converge.
  [in] | fits | If NULL, no output. If not NULL, file handle to output "resid vs time and its".

Returns
  Whether the algorithm finished successfully.

Here is the call graph for this function:

## ◆ dnrm2_()

double dnrm2_ | ( | int * | ,
|  | double | [],
|  | int * |
| ) |  |